<?php

namespace App\Console\Commands;

use Exception;
use Carbon\Carbon;
use App\Models\SafetyStock;
use App\Services\BaseService;
use App\Services\ConfigService;
use Illuminate\Console\Command;
use App\Services\ScheduleService;
use Illuminate\Support\Facades\DB;
use App\Repositories\BaseRepository;

class DailySave extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'daily:save';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = '每日資料紀錄';

    protected $scheduleService;
    protected $baseService;

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return mixed
     */
    public function handle()
    {
        $this->scheduleService = new ScheduleService();
        $baseRepository = new BaseRepository();
        $this->baseService = new BaseService($baseRepository, new ConfigService($baseRepository));

        $this->SaveProductInventory();
        $this->SaveSafetyStock();
    }

    /**
     * 總庫存紀錄
     *
     * @return void
     */
    private function SaveProductInventory()
    {
        try {
            //取得目前產品庫存
            $dbItem = DB::table('ITEM')
                ->select('ICODE', 'INUMB')
                ->where('INUMB', '!=', 0)
                ->distinct()
                ->get();
            //轉寫入陣列
            $datas = array();
            foreach ($dbItem as $value) {
                $icode = (string)$value->ICODE;
                $inumb = $value->INUMB;

                $datas[] = [
                    'ICODE' => $icode,
                    'INUMB' => $inumb
                ];
            }
            if (!empty($datas)) {
                //寫入資料庫
                DB::connection('mysql')
                    ->table('log_item')
                    ->insert($datas);
            }

            $this->scheduleService->CreateOnSuccessLog($this->signature, '總庫存紀錄');
        } catch (Exception $ex) {
            $this->scheduleService->CreateOnFailureLog($this->signature, '總庫存紀錄', $ex->getMessage());
        }
    }

    /**
     * 安全庫存紀錄
     *
     * @return void
     */
    private function SaveSafetyStock()
    {
        try {
            //清除舊的資料
            SafetyStock::where('created_at', '<=',  Carbon::now())->delete();
            $db = $this->baseService->GetSafetyStock();
            if (!empty($db)) {
                $data = array();
                foreach ($db as $item) {
                    $data[] = [
                        'supplier' => $item->IPNAM, //供應商名稱
                        'item_no' => $item->ICODE, //產品料號
                        'item_name' => $item->INAME, //產品名稱
                        'item_remark' => $item->T11_11, //產品備註
                        'stock' => $item->SNUMB, //庫存量
                        'daily_sales' => $item->DailySales, //每日銷售數
                        'remaining_day' => $item->RemainingDay, //庫存剩餘天數
                        'suggest' => $item->SuggestBuy, //建議採購量
                        'purchase_no' => $item->SCOD1, //最近採購單號
                        'inventory_date' => $item->UpdateDate, //最近盤點日期
                        'inventory_num' => $item->Quantity, //最近盤點數量
                    ];
                }
                //有資料才儲存
                if (count($data) > 0) {
                    SafetyStock::insert($data);
                }
            }
            $this->scheduleService->CreateOnSuccessLog($this->signature, '安全庫存紀錄');
        } catch (Exception $ex) {
            $this->scheduleService->CreateOnFailureLog($this->signature, '安全庫存紀錄', $ex->getMessage());
        }
    }
}
