<?php

namespace App\Http\Controllers;

use App\Models\Order;
use App\Models\OrderDetail;
use Illuminate\Http\Request;
use App\Services\BaseService;
use App\Models\CustomerComplaint;

class CustomerComplaintController extends Controller
{
    private $baseService = null;

    public function __construct(BaseService $baseService)
    {
        $this->baseService = $baseService;
    }

    //取得客訴單資料
    public function customer_complaint(Request $request)
    {
        $request->flash();
        $data = $this->baseService->GetCustomerComplaint($request);

        return view('customer_complaint', $data);
    }

    //AJAX 取得訂單資訊
    public function ajax_get_order(Request $request)
    {
        $order_no = $request->get('order_no', '');
        if (empty($order_no)) {
            return response()->json(['msg' => 'ERP/原始訂單編號為空'], 404);
        }
        $isExists = CustomerComplaint::where('status', '!=', '99')
            ->where(function ($query) use ($order_no) {
                $query
                    ->where('order_no', $order_no)
                    ->orWhere('origin_no', $order_no);
            })
            ->get()->count() > 0;
        if ($isExists) {
            return response()->json(['msg' => '訂單已經建立過客訴單'], 404);
        }
        $order = Order::select('OCNAM as source', 'OBAK2 as order_remark2', 'OCOD1 as order_no', 'OCOD4 as origin_no', 'OCCOD')
            ->where('OCOD4', $order_no)
            ->orWhere('OCOD1', $order_no)
            ->first();
        if (!empty($order)) {
            $order->OrderDetail = OrderDetail::select('OICOD as no', 'OINAM as name', 'OINUM as amount', 'OTOTA as total')
                ->where('OCOD1', $order->order_no)
                ->orderBy('OICOD')
                ->get();
        }

        return response()->json($order);
    }

    //新增客訴單
    public function create_customer_complaint(Request $request)
    {
        try {
            $customer_complaint = new CustomerComplaint;
            $customer_complaint->order_no = $request->get('order_no', '');
            $customer_complaint->origin_no = $request->get('origin_no', '');
            $customer_complaint->status = $request->get('status', '');
            $customer_complaint->remark = $request->get('remark', '');

            if ($customer_complaint->save()) {
                return redirect()->back()->with('status', '新增成功');
            } else {
                return redirect()->back()->with('status', '新增失敗');
            }
        } catch (\Exception  $ex) {
            return redirect()->back()->with('status', "新增失敗，原因：{$ex->getMessage()}");
        }
    }

    //編輯客訴單
    public function update_customer_complaint(Request $request)
    {
        try {
            $customer_complaint = CustomerComplaint::find($request->get('id', ''));
            if (empty($customer_complaint)) {
                return redirect()->back()->with('status', '編輯失敗');
            } else {
                $customer_complaint->status = $request->get('status', '');
                $customer_complaint->remark = $request->get('remark', '');
                if ($customer_complaint->save()) {
                    return redirect()->back()->with('status', '編輯成功');
                } else {
                    return redirect()->back()->with('status', '編輯失敗');
                }
            }
        } catch (\Exception  $ex) {
            return redirect()->back()->with('status', "編輯失敗，原因：{$ex->getMessage()}");
        }
    }
}
