<?php

namespace App\Http\Controllers;

use App\Models\OrderSampleM;
use Illuminate\Http\Request;
use App\Services\BaseService;
use App\Models\OrderSampleFile;
use App\Http\Controllers\Controller;

class OrderSampleController extends Controller
{
    private $baseService = null;

    public function __construct(BaseService $baseService)
    {
        $this->baseService = $baseService;
    }

    //特殊訂單管理
    public function index()
    {
        $data = $this->baseService->GetOrderSample();
        return view('order_sample', $data);
    }

    //特殊訂單轉檔下載頁面
    public function download_page()
    {
        $data = $this->baseService->GetOrderSampleDownload();
        return view('order_sample_download_page', $data);
    }

    //特殊訂單轉檔
    public function convert()
    {
        $data = $this->baseService->GetOrderSampleConvertView();
        return view('order_sample_convert', $data);
    }

    //確認樣片
    public function confirm(Request $request)
    {
        try {
            $idList = json_decode($request->get('id_list'));
            if (!empty($idList) && count($idList) > 0) {
                $orderSample = OrderSampleM::with('Edited')->whereIn('id', $idList)->where('confirmed', 0)->get();
                foreach ($orderSample as $item) {
                    $item->confirmed = 1;
                    $item->save();
                }

                return redirect()->back()->with('status', '確認成功');
            } else {
                return redirect()->back()->with('status', '確認失敗，原因：找不到勾選的訂單');
            }
        } catch (\Exception  $ex) {
            return redirect()->back()->with('status', "確認失敗，原因：{$ex->getMessage()}");
        }
    }

    //編輯訂單
    public function update(Request $request)
    {
        try {
            $id = $request->get('id');
            $orderSampleM = OrderSampleM::find($id);
            if (empty($orderSampleM)) {
                return redirect()->back()->with('status', "編輯失敗，原因：找不到該筆資料");
            } else {
                //基本資料編輯
                $orderSampleM->Edited()->updateOrCreate(
                    [
                        'm_id' => $orderSampleM->id,
                    ],
                    [
                        'remark' => $request->get('remark'),
                        'receiver_name' => $request->get('receiver_name'),
                        'receiver_tel' => $request->get('receiver_tel'),
                        'receiver_city' => $request->get('receiver_city'),
                        'receiver_district' => $request->get('receiver_district'),
                        'receiver_postal' => $request->get('receiver_postal'),
                        'receiver_address' => $request->get('receiver_address'),
                    ]
                );

                //正貨商品編輯
                $orderSampleM->EditedItem()->delete();
                $genuine_items = json_decode($request->get('genuine_items'), true);
                if (!empty($genuine_items) && count($genuine_items) > 0) {
                    foreach ($genuine_items as $genuine_item) {
                        $orderSampleM->EditedItem()->create($genuine_item);
                    }
                }

                return redirect()->back()->with('status', '編輯成功');
            }
        } catch (\Exception  $ex) {
            return redirect()->back()->with('status', "編輯失敗，原因：{$ex->getMessage()}");
        }
    }

    //刪除訂單
    public function delete(Request $request)
    {
        try {
            $id = $request->get('id');
            if (!empty($id)) {
                OrderSampleM::destroy($id);
                return redirect()->back()->with('status', '刪除成功');
            } else {
                return redirect()->back()->with('status', '刪除失敗，原因：找不到指定流水號');
            }
        } catch (\Exception  $ex) {
            return redirect()->back()->with('status', "刪除失敗，原因：{$ex->getMessage()}");
        }
    }
}
