<?php


namespace App\Http\Controllers;


use App\User;
use Carbon\Carbon;
use App\Models\Shift;
use Illuminate\Http\Request;
use App\Models\PackageShiftD;
use App\Models\PackageShiftM;
use App\Models\PackageMachine;
use Illuminate\Validation\Rule;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;

class PackageShiftController extends Controller
{

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    function __construct()
    {
        $this->middleware('permission:package_shift');
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $request->flash();
        $data = PackageShiftM::with('Details', 'Supervisor')->where('settle_date', $request->input('date', Carbon::today()->format('Y-m-d')))
            ->first();
        return view('package_shift.index', compact('data'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $users = User::all();
        $shifts = Shift::all();
        $machines = PackageMachine::all();
        return view('package_shift.create', compact('users', 'shifts', 'machines'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'date' => ['required', 'date'],
            'supervisor' => ['required', 'exists:mysql.users,id'],
            'shift' => ['required', 'exists:mysql.shift,id'],
            'machine' => ['required', 'exists:mysql.package_machine,id'],
            'check' => ['required', 'exists:mysql.users,id'],
            'package' => ['required', 'exists:mysql.users,id'],
        ]);

        $input = $request->all();
        $main = PackageShiftM::firstOrNew(
            ['settle_date' => $input['date']],
            ['supervisor' => $input['supervisor']]
        );

        //該日期有無設定紀錄，判斷是否重複
        if (!empty($main->id)) {
            $shift = $input['shift'];
            $machine = $input['machine'];
            $messages = ['unique' => ':attribute 重複，已有相同班別、機台'];
            $validator = Validator::make($request->all(), [
                'shift' => [
                    Rule::unique('mysql.package_shift_d')->where(function ($query) use ($main, $shift, $machine) {
                        return $query->where('m_id', $main->id)->where('shift', $shift)->where('machine', $machine)->whereNull('deleted_at');
                    })
                ],
                'machine' => [
                    Rule::unique('mysql.package_shift_d')->where(function ($query) use ($main, $shift, $machine) {
                        return $query->where('m_id', $main->id)->where('shift', $shift)->where('machine', $machine)->whereNull('deleted_at');
                    })
                ],
            ], $messages);
            if ($validator->fails()) {
                return redirect()->route('package_shift.create')->withErrors($validator)->withInput();
            }
        }
        $main->save();
        $main->Details()->create($input);

        return redirect()->route('package_shift.index')
            ->with('status', '排班新增成功');
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $package_shift_d = PackageShiftD::find($id);
        $package_shift_m = $package_shift_d->Main()->with('Supervisor')->first();
        $date = $package_shift_m->settle_date;
        $supervisor = $package_shift_m->Supervisor()->first()->name;
        $users = User::all();
        $shifts = Shift::all();
        $machines = PackageMachine::all();
        return view('package_shift.edit', compact('package_shift_d', 'date', 'supervisor', 'users', 'shifts', 'machines'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'shift' => ['required', 'exists:mysql.shift,id'],
            'machine' => ['required', 'exists:mysql.package_machine,id'],
            'check' => ['required', 'exists:mysql.users,id'],
            'package' => ['required', 'exists:mysql.users,id'],
        ]);

        PackageShiftD::find($id)->update($request->all());

        return redirect()->route('package_shift.index')
            ->with('status', '排班編輯成功');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        PackageShiftD::find($id)->delete();
        return redirect()->route('package_shift.index')
            ->with('status', '排班刪除成功');
    }
}
