<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Services\BaseService;
use Illuminate\Support\Facades\Auth;
use DB;
use Carbon\Carbon;
use DateTime;;
class PoseinCheckDataLogController extends Controller
{
    private $baseService = null;

    public function __construct(BaseService $baseService)
    {
        $this->baseService = $baseService;
    }

    //現場狀況
    public function index(Request $request)
    {
        $type = $request->type;

        $order = $this->baseService->GetOrderAll($request);
        $orderFaceToFace = $this->baseService->GetOrderFaceToFace($request);
        $transfer_count = $this->baseService->GetTransferData();
        $stock_check_count = $this->baseService->GetStockCheck();
        $salesFloor = $this->baseService->GetSalesFloor();
        $overweight = $this->baseService->GetOverweightOrder();
        $order_tax_id = $this->baseService->GetOrderTaxID($request);
        $orderBulb = $this->baseService->GetBulbOrder();
        $noPrint = $this->baseService->GetNoPrint($request);
        $salesCheckStatus = $this->baseService->GetSalesCheckStatus($request);
        $noCheck = $salesCheckStatus->where('CheckStatus', 1)->count();
        $checkout = $salesCheckStatus->where('CheckStatus', 2)->count();
        $nowPackageSpeed = $this->baseService->GetNowPackageSpeed();
        $production_progress = $this->baseService->GetProductionCurrentProgress();

        return view('check_table', [
            'noPrint' => empty($noPrint) ? 0 : count($noPrint), //未列印
            'checkFloorCount' => number_format($salesFloor), //本日重物件數
            'order_expired' => empty($order['expired']) ? 0 : count($order['expired']), //過期單
            'order_no_print' => empty($order['unprinted']) ? 0 : count($order['unprinted']), //未轉單
            'order_can_print' => empty($order['canPrint']) ? 0 : $order['canPrint'], //未轉單-可轉單
            'order_no_check' => empty($order['unchecked']) ? 0 : count($order['unchecked']), //未覆核
            'order_face_to_face' => empty($orderFaceToFace) ? 0 : count($orderFaceToFace), //面交單
            'no_check' => $noCheck, //未驗貨
            'checkout' => $checkout, //已出貨
            'orderWeight' => empty($overweight) ? 0 : count($overweight), //已超重
            'orderBulb' => empty($orderBulb) ? 0 : count($orderBulb), //需贈品
            'transfer_count' => empty($transfer_count) ? 0 : count($transfer_count), //可調撥
            'type' => $type, //圖表類型。1=重物
            'stock_check_count' => empty($stock_check_count) ? 0 : count($stock_check_count), //需採購
            'order_tax_id' => empty($order_tax_id) ? 0 : count($order_tax_id), //需統編
            'last_package_count' => $nowPackageSpeed['last'], //上個鐘頭驗貨完成速度
            'now_package_count' => $nowPackageSpeed['now'], //目前驗貨完成速度
            'production_progress' => $production_progress, //取得目前產品包裝進度
        ]);
    }

    //訂單狀況。未覆核、未轉單、已過期
    public function order($table, Request $request)
    {
        $data = $this->baseService->GetOrderAll($request);
        switch ($table) {
            case 'unchecked':
                $name = '未覆核';
                break;
            case 'unprinted':
                $name = '未轉單';
                break;
            case 'expired':
                $name = '已過期';
                break;
        }
        if (array_key_exists($table, $data)) {
            $data = $data[$table];
        } else {
            $data = array();
        }

        return view('order', ['data' => $data, 'name' => $name]);
    }

    //面交單
    public function order_face_to_face(Request $request)
    {
        $data = $this->baseService->GetOrderFaceToFace($request);
        return view('order', ['data' => $data, 'name' => '面交單']);
    }

    //未轉單總表
    public function order_unprinted()
    {
        $data = $this->baseService->GetOrderUnprinted();
        return view('order_unprinted', ['data' => $data]);
    }

    //未列印
    public function no_print(Request $request)
    {
        $data = $this->baseService->GetNoPrint($request);
        return view('sales', ['title' => '未列印', 'data' => $data]);
    }

    //搓合總表
    public function stock_check()
    {
        if (Auth::user()->can('package_shift') && !$this->baseService->HasPackageShift()) {
            return redirect()->route('package_shift.index')->with('status', '請先進行『包驗貨的排班』');
        } else {
            $data = $this->baseService->GetStockCheck();
            return view('rubbing', ['data' => $data]);
        }
    }

    //可調撥
    public function transfer()
    {
        $data =  $this->baseService->GetTransferData();
        return view('transfer', ['data' => $data]);
    }

    //庫存總表
    public function stockAll()
    {
        $data = $this->baseService->GetStockAll();
        return view('stock_all', ['data' => $data]);
    }

    //商品可銷售量表
    public function stock_can_sale(Request $request)
    {
        $request->flash();
        $data = $this->baseService->GetStockCanSale($request);
        return view('stock_can_sale', $data);
    }

    //儲位總表
    public function itemp()
    {
        $data = $this->baseService->GetStorageAll();
        return view('itemp', ['data' => $data]);
    }

    //訂單明細
    public function order_detail(Request $request)
    {
        $data = $this->baseService->GetOrderDetail($request);
        return view('order_detail', ['data' => $data]);
    }

    //銷售明細
    public function detail(Request $request)
    {
        $data = $this->baseService->GetSalesDetail($request);
        return view('check_detail', ['data' => $data]);
    }

    //查詢指定銷貨單號的資料
    public function check_search(Request $request)
    {
        $request->flash();
        $data = $this->baseService->GetSalesCheck($request);
        return view('check_search', ['data' => $data]);
    }

    //包裝速度
    public function package_speed(Request $request)
    {
        $request->flash();
        $data = $this->baseService->GetPackageSpeed($request);

        return view('package_speed', ['data' => $data]);
    }

    //託運總表
    public function transport(Request $request)
    {
        $request->flash();
        $data = $this->baseService->GetTransport($request);
        return view('transport', ['data' => $data]);
    }

    //託運明細
    public function transport_detail(Request $request)
    {
        $request->flash();
        $data = $this->baseService->GetTransportDetail($request);
        return view('transport_detail', ['data' => $data]);
    }

    //託運花費表
    public function transport_cost(Request $request)
    {
        $request->flash();
        $data = $this->baseService->GetTransportCost($request);
        return view('transport_cost', ['data' => $data]);
    }

    //已超重訂單
    public function overweight()
    {
        $data = $this->baseService->GetOverweightOrder();
        return view('order_weight', ['data' => $data, 'config' => BaseService::EARTH_WEIGHT_CONFIG]);
    }

    //需統編
    public function order_tax_id(Request $request)
    {
        $request->flash();
        $data = $this->baseService->GetOrderTaxID($request);
        return view('order_tax_id', ['data' => $data]);
    }

    //需贈品
    public function orderBulb()
    {
        $data = $this->baseService->GetBulbOrder();
        return view('order_bulb', ['orderData' => $data]);
    }

    //商品履歷
    public function item_log(Request $request)
    {
        $request->flash();
        $data = $this->baseService->GetItemLog($request);
        return view('item_log', $data);
    }

    //產品庫存紀錄
    public function item_history(Request $request)
    {
        $request->flash();
        $data = $this->baseService->GetItemHistory($request);
        return view('item_history', ['data' => $data]);
    }

    //銷售角度儲位調整
    public function sales_reserve()
    {
        $data = $this->baseService->GetSalesReserve();
        return view('sales_reserve', $data);
    }

    //未驗貨
    public function sales_unchecked(Request $request)
    {
        $data = $this->baseService->GetSalesCheckStatus($request)->where('CheckStatus', 1);
        return view('sales', ['title' => '未驗貨', 'data' => $data]);
    }

    //已出貨
    public function sales_checked(Request $request)
    {
        $data = $this->baseService->GetSalesCheckStatus($request)->where('CheckStatus', 2);
        return view('sales', ['title' => '已出貨', 'data' => $data]);
    }

    //孤兒單總表(有銷貨無驗貨紀錄)
    public function sales_lost_check()
    {
        $data = $this->baseService->GetSalesLostCheck();
        return view('sales_lost_check', ['data' => $data]);
    }

    //地板拖運數量查詢
    public function sales_count(Request $request)
    {
        $request->flash();
        $data = $this->baseService->GetSalesCount($request);
        return view('sales_count', ['data' => $data]);
    }

    //庫存異常
    public function stock_unusual()
    {
        $data = $this->baseService->GetStockUnusual();
        return view('stock_unusual', ['data' => $data]);
    }

    //滯銷商品表
    public function unsalable(Request $request)
    {
        $request->flash();
        $data = $this->baseService->GetUnsalable($request);
        return view('unsalable', ['data' => $data]);
    }

    //商品成長比較表
    public function sales_comparison(Request $request)
    {
        $request->flash();
        $data = $this->baseService->GetSalesComparison($request);
        return view('sales_comparison', $data);
    }

    //廣告每日花費
    public function ad_cost(Request $request)
    {
        $request->flash();
        $data =  $this->baseService->GetAdCost($request);
        return view('ad_cost', ['data' => $data]);
    }

    //廣告利潤
    public function ad_profit(Request $request)
    {
        $data = $request->session()->get('ad_profit_data', array());
        $data =  $this->baseService->GetAdProfit($data);
        return view('ad_profit', ['data' => $data]);
    }

    //查詢是否上車
    public function check_shipment(Request $request)
    {
        $data = $this->baseService->GetShipmentCheck($request);
        return view('check_shipment', $data);
    }

    //查詢銷貨業績以及未轉銷貨單
    public function sales_report(Request $request)
    {
        if (!Auth::user()->can('sales_report')) {
            return view('index');
        }
        if ($request->start_date) {
            $sDate = $this->baseService->GetTWDateStr(new DateTime($request->start_date));
            $eDate = $this->baseService->GetTWDateStr(new DateTime($request->end_date));
        } else {
            $sDate = $this->baseService->GetTWDateStr(Carbon::today());
            $eDate = $this->baseService->GetTWDateStr(Carbon::today());
            $request->start_date=date('Y-m-d');
            $request->end_date=date('Y-m-d');
        }
        //銷貨單
        $data = DB::table('POSEIN')->whereBetween('PDAT1', [$sDate, $eDate])->whereNotIn('PPCOD',['x001','x002'])->get();
        $dataSum = $data->sum('PTOTA');
        //未轉銷貨單
        $totalData = DB::table('ORDET AS O')
            ->leftJoin('POSEIN AS P', 'P.PCOD2', 'O.OCOD1')
            ->where('O.OCANC', '!=', '訂單取消')
            ->whereNull('P.PCOD2')
            ->orderBy('O.OCOD1');
        $totalDataSum = $totalData->sum('OTOT2');
        //銷貨退回
        $dataOut = DB::table('POSEOU')->whereBetween('PDAT1', [$sDate, $eDate]);
        $dataOut = $dataOut->sum('PTOTA');

        //銷貨明細
        $dataDetail = DB::table('HISTIN')->whereBetween('HDAT1', [$sDate, $eDate])->whereNotIn('HYNAM', ['其他', '包材'])->get();

        foreach ($dataDetail as $key => $value) {
            if(empty($NewDataDetail[$value->HYCOD.$value->HYNAM])){
                $NewDataDetail[$value->HYCOD.$value->HYNAM]=0;
            }
            $NewDataDetail[$value->HYCOD.$value->HYNAM]+=$value->HTOTA;
        }
        //pos機收入
        $posData = DB::table('PosMainTemp')->whereBetween('create_date', [$request->start_date . ' 00:00:00', $request->end_date . ' 23:59:59']);
        //pos機退貨
        $posReturnData = DB::table('PosReturnMainTemp')->whereBetween('create_date', [$request->start_date . ' 00:00:00', $request->end_date . ' 23:59:59']);;
        //pos機總額
        $posData = $posData->sum('SaleTotalMoney') - $posReturnData->sum('ReturnPayMoney');
        //pos機收入明細
        $posDataDetails = DB::table('PosDetailsTemp')->whereBetween('create_date', [$request->start_date . ' 00:00:00', $request->end_date . ' 23:59:59'])->get();

        foreach ($posDataDetails as $key => $value) {
            switch (substr($value->ICODE,0,2)) {
                case '10':
                    $str='10燈具';
                    break;
                case '11':
                    $str='11地板';
                    break;
                case '12':
                    $str='12生活用品';
                    break;
                case '13':
                    $str='13木器';
                    break;
                case '14':
                    $str='14冷氣';
                    break;
                case '20':
                    $str='20園藝';
                    break;
                default:
                    continue 2;
                    break;
            }
            if(empty($NewposDataDetails[$str])){
                $NewposDataDetails[$str]=0;
            }
            $NewposDataDetails[$str]+=$value->SaleMoneyTotal;
        }

        ksort($NewDataDetail);
        ksort($NewposDataDetails);

        return view('sales_report', ['NewDataDetail'=>$NewDataDetail,'NewposDataDetails'=>$NewposDataDetails,'dataOut'=>$dataOut,'data' => $data, 'dataSum' => $dataSum, 'totalDataSum' => $totalDataSum, 'posData' => $posData,'sDate'=>$sDate,'eDate'=>$eDate,]);
    }
}
