<?php

namespace App\Http\Controllers;

use App\Models\SafetyStock;
use Illuminate\Http\Request;
use App\Services\BaseService;
use App\Services\ConfigService;

class SafetyStockController extends Controller
{
    private $baseService = null;
    private $configService = null;

    public function __construct(BaseService $baseService, ConfigService $configService)
    {
        $this->baseService = $baseService;
        $this->configService = $configService;
    }

    //商品安庫表
    public function index(Request $request)
    {
        $data = $this->baseService->GetSafetyStockHistory($request);
        $users = $this->configService->GetConfig('users');
        return view('safety_stock', ['data' => $data, 'users' => $users]);
    }

    //編輯
    public function update(Request $request)
    {
        try {
            $id = $request->get('id', '');
            if (empty($id)) {
                return;
            }
            $safetyStock = SafetyStock::find($id);
            if (empty($safetyStock)) {
                return;
            }
            $safetyStock->remark = $request->get('remark', '');
            $safetyStock->save();

            return redirect()->back()->with('status', '編輯成功');
        } catch (\Exception $ex) {
            return redirect()->back()->with('status', "編輯失敗，原因：{$ex->getMessage()}");
        }
    }

    //覆核
    public function check(Request $request)
    {
        try {
            $id = $request->get('id', '');
            if (empty($id)) {
                return;
            }
            $safetyStock = SafetyStock::find($id);
            if (empty($safetyStock)) {
                return;
            }
            $safetyStock->signinger = $request->get('signinger', '');
            $safetyStock->save();

            return redirect()->back()->with('status', '覆核成功');
        } catch (\Exception $ex) {
            return redirect()->back()->with('status', "覆核失敗，原因：{$ex->getMessage()}");
        }
    }
}
