<?php

namespace App\Imports;

use Exception;
use Illuminate\Support\Collection;
use App\Repositories\BaseRepository;
use Maatwebsite\Excel\Concerns\ToCollection;

class AdProfitImport implements ToCollection
{
    public $data;
    public $msg = '';
    protected $type;

    public function __construct($type)
    {
        $this->type = $type;
    }

    public function collection(Collection $rows)
    {
        if (empty($rows) || $rows->count() == 0) {
            return;
        }
        switch ($this->type) {
            case '1':
                $this->ImportProfit($rows);
                break;
            case '2':
                $this->ImportItem($rows);
                break;
        }
    }

    /**
     * 商品對應表設定
     *
     * @param Collection $rows
     * @return void
     */
    private function ImportItem(Collection $rows)
    {
        $this->msg = '';
        $datas = array();
        try {
            foreach ($rows as $key => $row) {
                if ($key <= 3) { //略過標題
                    continue;
                }

                $commodityId = $row[0]; //商品ID
                if (!empty($row[6])) {
                    $itemId = $row[6]; //商品選項貨號
                } elseif (!empty($row[4])) {
                    $itemId = $row[4]; //主商品貨號
                } else {
                    continue;
                }
                $datas[$itemId] = $commodityId;
            }
            //寫入資料庫
            if (!empty($datas)) {
                (new BaseRepository())->SetAdItem($datas);
            }
        } catch (Exception $ex) {
            $this->msg = '商品對應表匯入錯誤。原因:' . $ex->getMessage();
        }
    }

    /**
     * 廣告效益
     *
     * @param Collection $rows
     * @return void
     */
    private function ImportProfit(Collection $rows)
    {
        $this->msg = '';
        $datas = array();
        try {
            $exportTime = gmdate('Y-m-d H:i:s', ($rows[2][1] - 25569) * 86400);
            $range = $rows[3][1];

            $data = array();
            for ($i = 7; $i < $rows->count(); $i++) {
                $productId = trim($rows[$i][3]); //商品ID
                $cost = $rows[$i][21]; //花費
                $salesAd = $rows[$i][20]; //直接銷售金額=廣告效益銷售額
                $salesTotal = $rows[$i][19]; //銷售金額=總銷售額
                $salesTotalCount = $rows[$i][17]; //銷售數

                //驗證
                if (!is_numeric($cost) || !is_numeric($salesAd) || !is_numeric($salesTotal) || !is_numeric($salesTotalCount)) {
                    $this->msg = '匯入的資料格式錯誤，無法分析，請重新匯入正確的檔案';
                    return;
                }

                if (array_key_exists($productId, $data)) {
                    $data[$productId]['cost'] += $cost;
                    $data[$productId]['salesAd'] += $salesAd;
                    $data[$productId]['salesTotal'] += $salesTotal;
                    $data[$productId]['salesTotalCount'] += $salesTotalCount;
                } else {
                    $data[$productId] = [
                        'cost' => $cost,
                        'salesAd' => $salesAd,
                        'salesTotal' => $salesTotal,
                        'salesTotalCount' => $salesTotalCount,
                    ];
                }
            }

            $datas = [
                'exportTime' => $exportTime,
                'range' => $range,
                'data' => $data
            ];
        } catch (Exception $ex) {
            $this->msg = '廣告效益匯入錯誤。原因:' . $ex->getMessage();
        }

        $this->data = $datas;
    }
}
