<?php

namespace App\Imports;

use Exception;
use App\Models\OrderSampleM;
use App\Services\BaseService;
use App\Services\ConfigService;
use Illuminate\Support\Collection;
use App\Repositories\BaseRepository;
use Maatwebsite\Excel\Concerns\ToCollection;

class OrderSampleImport implements ToCollection
{
    public $msg = '';

    protected $type;
    protected $baseRepository;
    protected $baseService;
    protected $configService;

    public function __construct($type)
    {
        $baseRepository = new BaseRepository();
        $configService = new ConfigService($baseRepository);
        $baseService = new BaseService($baseRepository, $configService);
        $this->type = $type;
        $this->baseRepository = $baseRepository;
        $this->configService = $configService;
        $this->baseService = $baseService;
    }

    public function collection(Collection $rows)
    {
        $this->msg = '';
        try {
            $this->ExcludeNull($rows);
            $header = $rows->first()->toArray();
            //驗證欄位
            if (!$this->Verify($header)) {
                return;
            }
            $headerData = json_encode($header);
            $columns = $this->baseService->GetOrderSampleColumns($header);
            if (empty($columns)) {
                $this->msg = '錯誤，匯入的資料當中找不到特定欄位';
                return;
            }

            //遍歷所有訂單資料，依訂單編號分組
            foreach ($rows->slice(1)->groupBy($columns['order_no']) as $orderNo => $group) {
                $originalData = json_encode($group); //原始資料轉JSON
                $row = $group->first(); //第一筆資料

                //更新或新增，訂單編號有重複的資料
                OrderSampleM::updateOrCreate(
                    [
                        'order_no' => $orderNo
                    ],
                    [
                        'order_date' => $row[$columns['order_date']], //訂單成立時間
                        'original_data' => $originalData,
                    ]
                );
            }
        } catch (Exception $ex) {
            $this->msg = '特殊訂單匯入發生無法預期的錯誤。原因:' . $ex->getMessage();
        }
    }

    /**
     * 驗證
     *
     * @param array $header
     * @return bool
     */
    private function Verify(array $header)
    {
        $config = $this->configService->GetConfig('order_convert_columns');
        if (empty($header) || empty($config)) {
            $this->msg = '錯誤，『匯入的標題欄位為空白』或者『欄位的設定檔未正確設定』';
            return false;
        } else {
            $unnecessaryMsg = '';
            $diffMsg = '';
            foreach ($header as $key => $value) {
                if (empty($config[$key])) { //未有設定的欄位
                    if (!empty($unnecessaryMsg)) { //添加斷點
                        $unnecessaryMsg .= '、';
                    }
                    $unnecessaryMsg .= "『{$value}』";
                } else {
                    if ($value != $config[$key]) { //與設定的欄位不同
                        if (!empty($diffMsg)) { //添加斷點
                            $diffMsg .= '、';
                        }
                        $diffMsg .= "『{$value}』必須為『{$config[$key]}』";
                    }
                }
            }
            if (!empty($diffMsg) || !empty($unnecessaryMsg)) {
                $this->msg = '錯誤，';
                if (!empty($diffMsg)) {
                    $this->msg .= '以下欄位與設定不同，' . $diffMsg . '。';
                }
                if (!empty($unnecessaryMsg)) {
                    $this->msg .= '以下為多餘欄位，' . $unnecessaryMsg . '。';
                }
                return false;
            } else {
                return true;
            }
        }
    }

    /**
     * 排除標頭為Null的資料
     *
     * @param Collection $rows
     * @return void
     */
    private function ExcludeNull(Collection &$rows)
    {
        if (!empty($rows)) {
            //取得Null的欄位索引
            $nullColumns = [];
            $header = $rows->first()->toArray();
            foreach ($header as $key => $value) {
                if ($value == null) {
                    $nullColumns[] = $key;
                }
            }
            //有空白的欄位
            if (!empty($nullColumns)) {
                foreach ($rows as $key => $row) {
                    //清空該欄位的每一列資料
                    foreach ($nullColumns as $index) {
                        $row->forget($index);
                    }
                    //reset index
                    $rows[$key] = $row->values();
                }
            }
        }
    }
}
